package com.daniel.bmicalculator

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.TextFieldValue
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.daniel.bmicalculator.ui.theme.BMICalculatorTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            BMICalculatorApp()
        }
    }
}

@Composable
fun BMICalculatorApp() {
    BMICalculatorScreen()
}

@Composable
fun BMICalculatorScreen() {
    var height by remember { mutableStateOf(TextFieldValue("")) }
    var weight by remember { mutableStateOf(TextFieldValue("")) }
    var bmiResult by remember { mutableStateOf<Float?>(null) }
    var bmiCategory by remember { mutableStateOf("") }
    var errorMessage by remember { mutableStateOf("") }

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Center
    ) {
        // Title
        Text("Kalkulator BMI", style = TextStyle(fontSize = 24.sp, fontWeight = FontWeight.Bold))

        Spacer(modifier = Modifier.height(16.dp))

        // Height Input
        Text("Tinggi Badan (cm):")
        TextField(
            value = height,
            onValueChange = { height = it },
            label = { Text("Masukkan Tinggi Badan (cm)") },
            modifier = Modifier
                .fillMaxWidth()
                .padding(8.dp)
                .border(1.dp, if (height.text.isNotEmpty() && height.text.toFloatOrNull() == null) Color.Red else Color.Gray)
                .padding(16.dp),
            isError = height.text.isNotEmpty() && height.text.toFloatOrNull() == null
        )

        Spacer(modifier = Modifier.height(16.dp))

        // Weight Input
        Text("Berat Badan (kg):")
        TextField(
            value = weight,
            onValueChange = { weight = it },
            label = { Text("Masukkan Berat Badan (kg)") },
            modifier = Modifier
                .fillMaxWidth()
                .padding(8.dp)
                .border(1.dp, if (weight.text.isNotEmpty() && weight.text.toFloatOrNull() == null) Color.Red else Color.Gray)
                .padding(16.dp),
            isError = weight.text.isNotEmpty() && weight.text.toFloatOrNull() == null
        )

        Spacer(modifier = Modifier.height(16.dp))

        // Calculate Button
        Button(
            onClick = {
                val heightInMeter = height.text.toFloatOrNull()?.div(100) ?: 0f
                val weightInKg = weight.text.toFloatOrNull() ?: 0f

                // Validate inputs
                if (heightInMeter > 0 && weightInKg > 0) {
                    bmiResult = weightInKg / (heightInMeter * heightInMeter)
                    bmiCategory = when {
                        bmiResult!! < 18.5 -> "Kekurangan Berat Badan"
                        bmiResult!! in 18.5..24.9 -> "Normal"
                        bmiResult!! in 25.0..29.9 -> "Kelebihan Berat Badan"
                        else -> "Obesitas"
                    }
                    errorMessage = "" // Reset error message
                } else {
                    bmiResult = null
                    bmiCategory = ""
                    errorMessage = "Tinggi dan Berat Badan harus valid dan lebih besar dari nol."
                }
            },
            modifier = Modifier
                .fillMaxWidth()
                .padding(8.dp)
        ) {
            Text("Hitung BMI")
        }

        Spacer(modifier = Modifier.height(16.dp))

        // Show error message if any
        errorMessage.takeIf { it.isNotEmpty() }?.let {
            Text(it, color = Color.Red)
        }

        // Show BMI result and category
        bmiResult?.let {
            Text("Hasil BMI: %.2f".format(it), style = TextStyle(fontSize = 20.sp), color = Color.Black)
            Text("Kategori: $bmiCategory", style = TextStyle(fontSize = 16.sp), color = Color.Black)
        }
    }
}

@Preview(showBackground = true)
@Composable
fun DefaultPreview() {
    BMICalculatorTheme {
        BMICalculatorApp()
    }
}
